@@ -12,18 +12,18 @@ AfcUrl::AfcUrl(const QUrl &url)
         return;
     }
 
-    m_device = url.host();
-
-    const int defaultPort = static_cast<int>(BrowseMode::FileSystem);
-    m_browseMode = static_cast<BrowseMode>(url.port(defaultPort));
-
+    m_device = url.host().toUpper();
     m_path = url.path();
 
     if (!m_path.isEmpty()) {
         Q_ASSERT(m_path.startsWith(QLatin1Char('/')));
     }
 
-    if (m_browseMode == BrowseMode::Apps) {
+    const QString appsPrefix = QLatin1Char('/') + appsTag();
+    if (m_path == appsPrefix || m_path.startsWith(appsPrefix + QLatin1Char('/'))) {
+        m_browseMode = BrowseMode::Apps;
+        m_path = m_path.mid(appsPrefix.length());
+
         int slashAfterAppIdx = m_path.indexOf(QLatin1Char('/'), 1);
         if (slashAfterAppIdx == -1) {
             slashAfterAppIdx = m_path.length();
@@ -31,6 +31,8 @@ AfcUrl::AfcUrl(const QUrl &url)
 
         m_appId = m_path.mid(1, slashAfterAppIdx - 1); // exclude slashes in app ID
         m_path = m_path.mid(slashAfterAppIdx); // include leading slash in path
+    } else {
+        m_browseMode = BrowseMode::FileSystem;
     }
 
     if (m_path == QLatin1Char('/')) {
@@ -67,3 +69,8 @@ bool AfcUrl::isValid() const
 {
     return m_browseMode == BrowseMode::FileSystem || m_browseMode == BrowseMode::Apps;
 }
+
+QString AfcUrl::appsTag()
+{
+    return QStringLiteral("@apps");
+}
