@@ -10,6 +10,7 @@
 
 #include "kio_filenamesearch_debug.h"
 
+#include <KFileItem>
 #include <KIO/FileCopyJob>
 #include <KIO/ListJob>
 #include <KLocalizedString>
@@ -50,6 +51,10 @@ bool hasBeenVisited(const QString &path, std::set<QString> &seenDirs)
     return false;
 }
 
+bool isDotOrDotDot(const QString &fileName)
+{
+    return fileName == QLatin1String(".") || fileName == QLatin1String("..");
+}
 }
 
 // Pseudo plugin class to embed meta data
@@ -95,11 +100,14 @@ static bool contentContainsPattern(const QUrl &url, const QRegularExpression &re
     return false;
 }
 
-static bool match(const KIO::UDSEntry &entry, const QRegularExpression &regex, bool searchContents)
+//  Search for a term in the filename and then, if SearchContent set, in the body of the file
+
+bool FileNameSearchProtocol::match(const KIO::UDSEntry &entry, const QRegularExpression &regex, const SearchOptions options)
 {
-    if (!searchContents) {
-        return regex.match(entry.stringValue(KIO::UDSEntry::UDS_NAME)).hasMatch();
-    } else {
+    if (options.testFlag(SearchFileName) && regex.match(entry.stringValue(KIO::UDSEntry::UDS_NAME)).hasMatch()) {
+        return true;
+    }
+    if (options.testFlags(SearchContent)) {
         const QUrl entryUrl(entry.stringValue(KIO::UDSEntry::UDS_URL));
         QMimeDatabase mdb;
         QMimeType mimetype = mdb.mimeTypeForUrl(entryUrl);
@@ -192,17 +200,36 @@ KIO::WorkerResult FileNameSearchProtocol::listDir(const QUrl &url)
         return KIO::WorkerResult::pass();
     }
 
-    const bool isContent = urlQuery.queryItemValue(QStringLiteral("checkContent")) == QLatin1String("yes");
-    const bool includeHidden = urlQuery.queryItemValue(QStringLiteral("includeHidden")) == QLatin1String("yes");
+    const QString optionContent = urlQuery.queryItemValue(QStringLiteral("checkContent"));
+    const QString optionHidden = urlQuery.queryItemValue(QStringLiteral("includeHidden"));
+    const QString optionSrc = urlQuery.queryItemValue(QStringLiteral("src"));
 
-    // These are placeholders, the longer term aim is something a bit more flexible.
-    // The default behaviour is to assume the external script is present and fall back to using the
+    SearchOptions options(SearchFileName);
+
+    // "checkContent=yes" should also search for terms in the filename.
+    if (QString::compare(optionContent, QLatin1String("yes"), Qt::CaseInsensitive) == 0) {
+        options.setFlag(SearchContent);
+    }
+
+    // "includeHidden=yes" should search for hidden files and within hidden folders
+    if (QString::compare(optionHidden, QLatin1String("yes"), Qt::CaseInsensitive) == 0) {
+        options.setFlag(IncludeHidden);
+    } else if (QString::compare(optionHidden, QLatin1String("filesandfolders"), Qt::CaseInsensitive) == 0) {
+        options.setFlag(IncludeHidden);
+    } else if (QString::compare(optionHidden, QLatin1String("folders"), Qt::CaseInsensitive) == 0) {
+        options.setFlag(IncludeHiddenFolders);
+    } else if (QString::compare(optionHidden, QLatin1String("files"), Qt::CaseInsensitive) == 0) {
+        options.setFlag(IncludeHiddenFiles);
+    }
+
+    // Default behaviour is to assume the external script is present and fall back to using the
     // internal search if it is not.
+    // "src=internal" should use only the internal simple search code, "src=external" should call the external script
 
     Engine useEngine = Unspecified;
-    if (urlQuery.queryItemValue(QStringLiteral("src")) == QLatin1String("internal")) {
+    if (QString::compare(optionSrc, QLatin1String("internal"), Qt::CaseInsensitive) == 0) {
         useEngine = Internal;
-    } else if (urlQuery.queryItemValue(QStringLiteral("src")) == QLatin1String("external")) {
+    } else if (QString::compare(optionSrc, QLatin1String("external"), Qt::CaseInsensitive) == 0) {
         useEngine = External;
     }
 
@@ -211,7 +238,7 @@ KIO::WorkerResult FileNameSearchProtocol::listDir(const QUrl &url)
 
 #if !defined(Q_OS_WIN32)
     // Prefer using external tools if available
-    if ((useEngine == Unspecified || useEngine == External) && isContent && dirUrl.isLocalFile()) {
+    if ((useEngine == Unspecified || useEngine == External) && options.testFlag(SearchContent) && dirUrl.isLocalFile()) {
         KIO::WorkerResult result = searchDirWithExternalTool(dirUrl, regex);
         if (result.error() != KIO::ERR_UNSUPPORTED_ACTION) {
             return result;
@@ -226,12 +253,12 @@ KIO::WorkerResult FileNameSearchProtocol::listDir(const QUrl &url)
 #endif
 
     if (useEngine == Unspecified || useEngine == Internal) {
-        searchDir(dirUrl, regex, isContent, includeHidden, iteratedDirs, pendingDirs);
+        searchDir(dirUrl, regex, options, iteratedDirs, pendingDirs);
 
         while (!pendingDirs.empty()) {
             const QUrl pendingUrl = pendingDirs.front();
             pendingDirs.pop();
-            searchDir(pendingUrl, regex, isContent, includeHidden, iteratedDirs, pendingDirs);
+            searchDir(pendingUrl, regex, options, iteratedDirs, pendingDirs);
         }
     }
 
@@ -240,8 +267,7 @@ KIO::WorkerResult FileNameSearchProtocol::listDir(const QUrl &url)
 
 void FileNameSearchProtocol::searchDir(const QUrl &dirUrl,
                                        const QRegularExpression &regex,
-                                       bool searchContents,
-                                       bool includeHidden,
+                                       const SearchOptions options,
                                        std::set<QString> &iteratedDirs,
                                        std::queue<QUrl> &pendingDirs)
 {
@@ -255,7 +281,7 @@ void FileNameSearchProtocol::searchDir(const QUrl &dirUrl,
     }
 
     KIO::ListJob::ListFlags listFlags = {};
-    if (includeHidden) {
+    if (options.testAnyFlags(IncludeHidden)) {
         listFlags = KIO::ListJob::ListFlag::IncludeHidden;
     }
     KIO::ListJob *listJob = KIO::listRecursive(dirUrl, KIO::HideProgressInfo, listFlags);
@@ -279,10 +305,15 @@ void FileNameSearchProtocol::searchDir(const QUrl &dirUrl,
                 return;
             }
 
-            // UDS_NAME is e.g. "foo/bar/somefile.txt"
-            const QString leaf = path + entry.stringValue(KIO::UDSEntry::UDS_NAME);
+            // Create a KFileItem that assumes dirUrl is a folder and delays mimetype resolution.
+            const KFileItem item(entry, dirUrl, true, true);
 
-            if (!hasBeenVisited(leaf, iteratedDirs)) {
+            // UDS_NAME is e.g. "foo/bar/somefile.txt"
+            const QString leaf = path + item.name();
+
+            //  .. Avoid dot and dotdot
+
+            if (!isDotOrDotDot(entry.stringValue(KIO::UDSEntry::UDS_NAME)) && !hasBeenVisited(leaf, iteratedDirs)) {
                 entryUrl.setPath(leaf);
 
                 const QString urlStr = entryUrl.toDisplayString();
@@ -291,20 +322,37 @@ void FileNameSearchProtocol::searchDir(const QUrl &dirUrl,
                 const QString fileName = entryUrl.fileName();
                 entry.replace(KIO::UDSEntry::UDS_NAME, fileName);
 
-                //  There's no point in trying to search content if the entry is a folder, however the code should
-                //  check the foldername. This is a "TODO" for when a content search also checks filenames.
-
-                if (entry.isDir()) {
+                if (item.isDir()) {
                     // Push the symlink destination into the queue, leaving the decision
                     // of whether to actually search the folder to later
 
-                    if (const QString linkDest = entry.stringValue(KIO::UDSEntry::UDS_LINK_DEST); !linkDest.isEmpty()) {
-                        pendingDirs.push(entryUrl.resolved(QUrl(linkDest)));
-                    }
-                }
+                    // However only do this if the symlink is not hidden or IncludeHiddenFolders is set
+                    // If the folder is hidden, add it to iteratedDirs to stop it being exlored
+                    // (Assume ListRecursive returns the folder name before exploring the folder).
 
-                if (match(entry, regex, searchContents)) {
-                    // UDS_DISPLAY_NAME is e.g. "foo/bar/somefile.txt"
+                    if ((!item.isHidden()) || options.testFlag(IncludeHiddenFolders)) {
+                        const QString linkDest = entry.stringValue(KIO::UDSEntry::UDS_LINK_DEST);
+                        if (!linkDest.isEmpty()) {
+                            pendingDirs.push(entryUrl.resolved(QUrl(linkDest)));
+                        }
+                    } else {
+                        iteratedDirs.insert(leaf);
+                    }
+
+                    //  There's no point in trying to search content if the entry is a folder so drop
+                    //  the SearchContent flag.
+
+                    SearchOptions folderOptions = options;
+                    folderOptions.setFlag(SearchContent, false);
+
+                    //  UDS_DISPLAY_NAME is e.g. "foo/bar/somefile.txt"
+
+                    if ((!item.isHidden() || options.testFlag(IncludeHiddenFiles)) && match(entry, regex, folderOptions)) {
+                        entry.replace(KIO::UDSEntry::UDS_DISPLAY_NAME, fileName);
+                        listEntry(entry);
+                    }
+
+                } else if ((!item.isHidden() || options.testFlag(IncludeHiddenFiles)) && match(entry, regex, options)) {
                     entry.replace(KIO::UDSEntry::UDS_DISPLAY_NAME, fileName);
                     listEntry(entry);
                 }
