@@ -53,7 +53,7 @@ InfoProtocol::InfoProtocol(const QByteArray &pool, const QByteArray &app)
     qCDebug(LOG_KIO_INFO) << "done";
 }
 
-KIO::WorkerResult InfoProtocol::missingFilesReult() const
+KIO::WorkerResult InfoProtocol::missingFilesResult() const
 {
     const QString errorStr = i18n(
         "Unable to locate files which are necessary to run this service:<br>%1<br>"
@@ -67,7 +67,7 @@ KIO::WorkerResult InfoProtocol::get(const QUrl &url)
     qCDebug(LOG_KIO_INFO) << "URL" << url.toDisplayString() << "path" << url.path();
 
     if (!m_missingFiles.isEmpty()) {
-        return missingFilesReult();
+        return missingFilesResult();
     }
 
     if (url.path() == "/") {
@@ -125,8 +125,10 @@ KIO::WorkerResult InfoProtocol::get(const QUrl &url)
         return KIO::WorkerResult::fail(ERR_CANNOT_LAUNCH_PROCESS, cmd);
     }
 
-    char buffer[4096];
+    auto fileCloser = [](FILE* f) { if(f) pclose(f); };
+    std::unique_ptr<FILE, decltype(fileCloser)> fileGuard(file);
 
+    char buffer[4096];
     bool empty = true;
     while (!feof(file)) {
         int n = fread(buffer, 1, sizeof(buffer), file);
@@ -136,7 +138,6 @@ KIO::WorkerResult InfoProtocol::get(const QUrl &url)
         if (n < 0) {
             // ERROR
             qCWarning(LOG_KIO_INFO) << "read error!";
-            pclose(file);
             return KIO::WorkerResult::fail();
         }
 
@@ -144,10 +145,7 @@ KIO::WorkerResult InfoProtocol::get(const QUrl &url)
         data(QByteArray::fromRawData(buffer, n));
     }
 
-    pclose(file);
-
     qCDebug(LOG_KIO_INFO) << "done";
-
     return KIO::WorkerResult::pass();
 }
 
@@ -156,7 +154,7 @@ KIO::WorkerResult InfoProtocol::mimetype(const QUrl & /* url */)
     qCDebug(LOG_KIO_INFO);
 
     if (!m_missingFiles.isEmpty()) {
-        return missingFilesReult();
+        return missingFilesResult();
     }
 
     // to get rid of those "Open with" dialogs...
@@ -228,7 +226,7 @@ void InfoProtocol::decodePath(QString path)
 KIO::WorkerResult InfoProtocol::stat(const QUrl &)
 {
     if (!m_missingFiles.isEmpty()) {
-        return missingFilesReult();
+        return missingFilesResult();
     }
 
     UDSEntry uds_entry;
