@@ -101,8 +101,8 @@ QVariant ProvidersModel::data(const QModelIndex &index, int role) const
     if (role == Qt::ToolTipRole || role == Qt::WhatsThisRole) {
         if (index.column() == Preferred) {
             return xi18nc("@info:tooltip",
-                          "Check this box to select the highlighted web search keyword "
-                          "as preferred.<nl/>Preferred web search keywords are used in "
+                          "Check this box to select the highlighted Web search keyword "
+                          "as preferred.<nl/>Preferred Web search keywords are used in "
                           "places where only a few select keywords can be shown "
                           "at one time.");
         }
@@ -461,3 +461,7 @@ void FilterOptions::updateSearchProviderEditingButons()
 K_PLUGIN_CLASS_WITH_JSON(FilterOptions, "kcm_webshortcuts.json")
 
 #include "ikwsopts.moc"
+
+#include "moc_ikwsopts.cpp"
+
+#include "moc_ikwsopts_p.cpp"
