@@ -23,8 +23,8 @@
 
 #include <memory>
 
-#include <QFile>
 #include <QEventLoop>
+#include <QFile>
 #include <QMimeDatabase>
 #include <QMimeType>
 #include <QProcess>
@@ -51,9 +51,7 @@ KIO::ThumbnailResult ComicCreator::create(const KIO::ThumbnailRequest &request)
     if (mime.inherits("application/x-cbz") || mime.inherits("application/zip")) {
         // ZIP archive.
         cover = extractArchiveImage(path, ZIP);
-    } else if (mime.inherits("application/x-cbt") ||
-               mime.inherits("application/x-gzip") ||
-               mime.inherits("application/x-tar")) {
+    } else if (mime.inherits("application/x-cbt") || mime.inherits("application/x-gzip") || mime.inherits("application/x-tar")) {
         // TAR archive
         cover = extractArchiveImage(path, TAR);
     } else if (mime.inherits("application/x-cb7") || mime.inherits("application/x-7z-compressed")) {
@@ -71,43 +69,38 @@ KIO::ThumbnailResult ComicCreator::create(const KIO::ThumbnailRequest &request)
     return KIO::ThumbnailResult::pass(cover);
 }
 
-void ComicCreator::filterImages(QStringList& entries)
+void ComicCreator::filterImages(QStringList &entries)
 {
     /// Sort case-insensitive, then remove non-image entries.
     QMap<QString, QString> entryMap;
-    for (const QString& entry : qAsConst(entries)) {
+    for (const QString &entry : qAsConst(entries)) {
         // Skip MacOS resource forks
-        if (entry.startsWith(QLatin1String("__MACOSX"), Qt::CaseInsensitive) ||
-                entry.startsWith(QLatin1String(".DS_Store"), Qt::CaseInsensitive)) {
+        if (entry.startsWith(QLatin1String("__MACOSX"), Qt::CaseInsensitive) || entry.startsWith(QLatin1String(".DS_Store"), Qt::CaseInsensitive)) {
             continue;
         }
-        if (entry.endsWith(QLatin1String(".avif"), Qt::CaseInsensitive) ||
-                entry.endsWith(QLatin1String(".bmp"), Qt::CaseInsensitive) ||
-                entry.endsWith(QLatin1String(".gif"), Qt::CaseInsensitive) ||
-                entry.endsWith(QLatin1String(".heif"), Qt::CaseInsensitive) ||
-                entry.endsWith(QLatin1String(".jpg"), Qt::CaseInsensitive) ||
-                entry.endsWith(QLatin1String(".jpeg"), Qt::CaseInsensitive) ||
-                entry.endsWith(QLatin1String(".jxl"), Qt::CaseInsensitive) ||
-                entry.endsWith(QLatin1String(".png"), Qt::CaseInsensitive) ||
-                entry.endsWith(QLatin1String(".webp"), Qt::CaseInsensitive)) {
+        if (entry.endsWith(QLatin1String(".avif"), Qt::CaseInsensitive) || entry.endsWith(QLatin1String(".bmp"), Qt::CaseInsensitive)
+            || entry.endsWith(QLatin1String(".gif"), Qt::CaseInsensitive) || entry.endsWith(QLatin1String(".heif"), Qt::CaseInsensitive)
+            || entry.endsWith(QLatin1String(".jpg"), Qt::CaseInsensitive) || entry.endsWith(QLatin1String(".jpeg"), Qt::CaseInsensitive)
+            || entry.endsWith(QLatin1String(".jxl"), Qt::CaseInsensitive) || entry.endsWith(QLatin1String(".png"), Qt::CaseInsensitive)
+            || entry.endsWith(QLatin1String(".webp"), Qt::CaseInsensitive)) {
             entryMap.insert(entry.toLower(), entry);
         }
     }
     entries = entryMap.values();
 }
 
-QImage ComicCreator::extractArchiveImage(const QString& path, const ComicCreator::Type type)
+QImage ComicCreator::extractArchiveImage(const QString &path, const ComicCreator::Type type)
 {
     /// Extracts the cover image out of the .cbz or .cbt file.
     QScopedPointer<KArchive> cArchive;
 
-    if (type==ZIP) {
+    if (type == ZIP) {
         // Open the ZIP archive.
         cArchive.reset(new KZip(path));
-    } else if (type==TAR) {
+    } else if (type == TAR) {
         // Open the TAR archive.
         cArchive.reset(new KTar(path));
-    } else if (type==SEVENZIP) {
+    } else if (type == SEVENZIP) {
         // Open the 7z archive.
         cArchive.reset(new K7Zip(path));
     } else {
@@ -121,7 +114,7 @@ QImage ComicCreator::extractArchiveImage(const QString& path, const ComicCreator
     }
 
     // Get the archive's directory.
-    const KArchiveDirectory* cArchiveDir = nullptr;
+    const KArchiveDirectory *cArchiveDir = nullptr;
     cArchiveDir = cArchive->directory();
     if (!cArchiveDir) {
         return QImage();
@@ -137,8 +130,7 @@ QImage ComicCreator::extractArchiveImage(const QString& path, const ComicCreator
     }
 
     // Extract the cover file.
-    const KArchiveFile *coverFile = static_cast<const KArchiveFile*>
-                                    (cArchiveDir->entry(entries[0]));
+    const KArchiveFile *coverFile = static_cast<const KArchiveFile *>(cArchiveDir->entry(entries[0]));
     if (!coverFile) {
         return QImage();
     }
@@ -146,25 +138,21 @@ QImage ComicCreator::extractArchiveImage(const QString& path, const ComicCreator
     return QImage::fromData(coverFile->data());
 }
 
-
-
-void ComicCreator::getArchiveFileList(QStringList& entries, const QString& prefix,
-                                      const KArchiveDirectory *dir)
+void ComicCreator::getArchiveFileList(QStringList &entries, const QString &prefix, const KArchiveDirectory *dir)
 {
     /// Recursively list all files in the ZIP archive into 'entries'.
     const auto dirEntries = dir->entries();
-    for (const QString& entry : dirEntries) {
+    for (const QString &entry : dirEntries) {
         const KArchiveEntry *e = dir->entry(entry);
         if (e->isDirectory()) {
-            getArchiveFileList(entries, prefix + entry + '/',
-                               static_cast<const KArchiveDirectory*>(e));
+            getArchiveFileList(entries, prefix + entry + '/', static_cast<const KArchiveDirectory *>(e));
         } else if (e->isFile()) {
             entries.append(prefix + entry);
         }
     }
 }
 
-QImage ComicCreator::extractRARImage(const QString& path)
+QImage ComicCreator::extractRARImage(const QString &path)
 {
     /// Extracts the cover image out of the .cbr file.
 
@@ -193,8 +181,7 @@ QImage ComicCreator::extractRARImage(const QString& path)
     return cover;
 }
 
-QStringList ComicCreator::getRARFileList(const QString& path,
-        const QString& unrarPath)
+QStringList ComicCreator::getRARFileList(const QString &path, const QString &unrarPath)
 {
     /// Get a verbose unrar listing so we can extract a single file later.
     // CMD: unrar vb /path/to/archive
@@ -218,8 +205,7 @@ QString ComicCreator::unrarPath() const
         QProcess proc;
         proc.start(unrar, {"-version"});
         proc.waitForFinished(-1);
-        const QStringList lines = QString::fromLocal8Bit(proc.readAllStandardOutput()).split
-                                  ('\n', Qt::SkipEmptyParts);
+        const QStringList lines = QString::fromLocal8Bit(proc.readAllStandardOutput()).split('\n', Qt::SkipEmptyParts);
         if (!lines.isEmpty()) {
             if (lines.first().startsWith(QLatin1String("RAR ")) || lines.first().startsWith(QLatin1String("UNRAR "))) {
                 return unrar;
@@ -230,7 +216,7 @@ QString ComicCreator::unrarPath() const
     return QString();
 }
 
-int ComicCreator::runProcess(const QString& processPath, const QStringList& args)
+int ComicCreator::runProcess(const QString &processPath, const QStringList &args)
 {
     /// Run a process and store stdout data in a buffer.
 
